@@ -22,13 +22,18 @@ from .models import User, Organization, ModelKey, UserState
 
 class TransformAuth:  # noqa: D
     def __init__(  # noqa: D
-        self, api_key: Optional[str] = None, mql_server_url: Optional[str] = None, override_config: bool = True
+        self,
+        api_key: Optional[str] = None,
+        mql_server_url: Optional[str] = None,
+        override_config: bool = True,
+        use_async: bool = False,
     ) -> None:
         self.__user_state: Optional[UserState] = None
         self.__mql_server_url: Optional[str] = None
         self.__mql_client: Optional[MQLInterface] = None
         self.__auth_header: Optional[Dict[str, str]] = None
         self.__api_key: Optional[str] = None
+        self._use_async = use_async
         self.config = ConfigHandler(override_config)
 
         # Overrides
@@ -102,7 +107,7 @@ class TransformAuth:  # noqa: D
         backend_override = self.config._get_config_value(BACKEND_OVERRIDE_CONFIG_KEY)
         if backend_override:
             overrides["rest_api_url"] = backend_override
-        return BackendInterface(auth_header=self.auth_header, **overrides)
+        return BackendInterface(auth_header=self.auth_header, use_async=self._use_async, **overrides)
 
     @property
     def user_state(self) -> UserState:  # noqa: D
@@ -163,7 +168,9 @@ class TransformAuth:  # noqa: D
     @property
     def mql_client(self) -> MQLInterface:  # noqa: D
         if not self.__mql_client:
-            self.__mql_client = MQLInterface(query_server_url=self.mql_server_url, auth_header=self.auth_header)
+            self.__mql_client = MQLInterface(
+                query_server_url=self.mql_server_url, auth_header=self.auth_header, use_async=self._use_async
+            )
         return self.__mql_client
 
 
