@@ -291,10 +291,10 @@ class BackendInterface(BaseInterface):  # noqa: D
     def get_org_mql_servers(self) -> List[MQLServer]:  # noqa: D
         query = gql(
             """
-            query MqlServersQuery {
+            query MqlServersQuery ($pageSize: Int!){
                 myUser {
                     organization {
-                        mqlServers {
+                        mqlServers (pageSize: $pageSize) {
                             id
                             name
                             url
@@ -306,7 +306,12 @@ class BackendInterface(BaseInterface):  # noqa: D
             """
         )
 
-        return [MQLServer.from_gql_dict(s) for s in self.execute(query)["myUser"]["organization"]["mqlServers"]]
+        return [
+            MQLServer.from_gql_dict(s)
+            for s in self.execute(query, variable_values={"pageSize": MAX_PAGE_SIZE})["myUser"]["organization"][
+                "mqlServers"
+            ]
+        ]
 
     def get_user_state(self) -> UserState:
         """Fetch all the core models for the User/Org/current model in one simple query"""
